<?php
	namespace ElementorPro\Modules\Posts\Skins;

	use Elementor\Controls_Manager;
	use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
	use Elementor\Group_Control_Image_Size;
    use Elementor\Plugin;
    use Elementor\Widget_Base;

	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly
	}

	/**
	 * Custom posts skin for blog - to show the category
	 * Class Posts_Skin_Blog
	 * @package ElementorPro\Modules\Posts\Skins
	 */
	class Posts_Skin_Blog extends Skin_Classic {

		public function get_id() {
			return 'classic_posts_blog';
		}

		public function get_title() {
			return 'Custom Blog Layout';
		}


		// add the elementor-has-item-ratio class to the element
		//public function get_container_class() {
		//	return 'elementor-has-item-ratio elementor-posts--skin-' . $this->get_id();
		//}

		public function register_controls( Widget_Base $widget ) {
			parent::register_controls($widget);
			$this->parent = $widget;

			$this->remove_control('masonry');
			$this->remove_control('thumbnail');
			$this->remove_control('thumbnail_size');
			$this->remove_control('item_ratio');
			$this->remove_control('show_excerpt');
			$this->remove_control('show_title');
			$this->remove_control('excerpt_length');
			$this->remove_control('show_read_more');
			$this->remove_control('read_more_text');
			$this->remove_control('open_new_tab');
			$this->remove_control('meta_separator');
			$this->remove_control('title_tag');
		}

		protected function _register_controls_actions() {
			parent::_register_controls_actions();
			$widget_name = $this->parent->get_name();
			add_action( 'elementor/element/' . $widget_name . '/section_layout/before_section_end', [ $this, 'register_extra_layout_controls' ] );
		}

		public function register_extra_layout_controls() {
			$this->add_control(
				'mb_cta_color',
				[
					'label' => esc_html__( 'CTA Color', 'elementor' ),
					'type' => Controls_Manager::COLOR,
					'global' => [
						'default' => Global_Colors::COLOR_PRIMARY,
					],
					'selectors' => [
						'{{WRAPPER}} .mb-blog-posts .elementor-post__data' => 'background: {{VALUE}};',
					],
				]
			);
		}

		protected function render_post() {
			$this->render_post_header();
			$this->render_post_content();
			/*$this->render_thumbnail();
			$this->render_text_header();
			$this->render_title();
			$this->render_meta_data();
			$this->render_excerpt();
			$this->render_read_more();
			$this->render_text_footer();*/
			$this->render_post_footer();
		}

		protected function render_loop_header() {
			$this->parent->add_render_attribute( 'container', [
				'class' => 'mb-blog-posts',
			] );

			parent::render_loop_header();
		}

		protected function render_post_content() {
			// get thumbnail src
			$settings = $this->parent->get_settings();
			$image_src = Group_Control_Image_Size::get_attachment_image_src( get_post_thumbnail_id(), 'classic_product_archive_thumbnail_size_size', $settings );
			$optional_attributes_html = $this->get_optional_link_attributes_html();

			// get main category
			$cats = get_the_category();
			if($cats) {
				$category = array_shift($cats);
			}

			// meta data
			$meta = $this->get_instance_value( 'meta_data' );

			?>
			<a class="elementor-post__container"
               href="<?php echo esc_attr( $this->current_permalink ); ?>" <?php echo esc_attr( $optional_attributes_html ); ?>>
				<div class="elementor-post__content" style="background-image: url('<?php echo esc_attr($image_src); ?>');">
					<div class="elementor-post__category">
						<?php if($category): ?>
							<span><?php echo esc_html($category->name); ?></span>
						<?php endif; ?>
					</div>
					<div class="elementor-post__data">
						<h5 class="elementor-post__thetitle"><?php the_title(); ?></h5>
						<?php if(in_array('date', $meta)): ?>
							<div class="elementor-post__date"><?php echo get_the_date(); ?></div>
						<?php endif; ?>
					</div>
				</div>
			</a>
			<?php
		}
	}
