<?php
	namespace Elementor;

	use Elementor\Core\Kits\Documents\Tabs\Global_Colors;

	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	/**
	 * Builder Elementor Widget
	 */
	class Widget_MB_CTA extends Widget_Base {

		public function get_name() {
			return 'mb-cta-widget';
		}

		public function get_title() {
			return __( 'MB CTA Widget', 'mb' );
		}

		public function get_icon() {
			// @see https://elementor.github.io/elementor-icons/
			return 'eicon-image-rollover';
		}

		public function get_keywords() {
			return [ 'mb', 'mbaierl', 'user', 'cta', 'client', 'kunde', ];
		}

		/**
		 * Register icon list widget controls.
		 *
		 * Adds different input fields to allow the user to change and customize the widget settings.
		 *
		 * @since 1.0.0
		 * @access protected
		 */
		protected function register_controls() {
			$this->start_controls_section(
				'section_cta_widget',
				[
					'label' => __( 'CTA Widget', 'mb' ),
				]
			);

			$this->add_control(
				'default_image',
				[
					'label' => __( 'Choose Image', 'elementor-pro' ),
					'type' => Controls_Manager::MEDIA,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
					'selectors' => [
                        '{{WRAPPER}} .mb-cta__overlay' => 'background-image: url({{URL}})',
					],
				]
			);

			$this->add_responsive_control(
				'image_ratio',
				[
					'label' => __( 'Image Ratio', 'elementor-pro' ),
					'type' => Controls_Manager::SLIDER,
					'default' => [
						'size' => 0.66,
					],
					'tablet_default' => [
						'size' => '',
					],
					'mobile_default' => [
						'size' => '',
					],
					'range' => [
						'px' => [
							'min' => 0.1,
							'max' => 2,
							'step' => 0.01,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .mb-cta' => '--mb-aspect-ratio: {{SIZE}};',
					],
				]
			);

			$this->add_control(
				'title',
				[
					'label' => __( 'CTA Inhalt', 'elementor' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => 'Content',
					'dynamic' => [
						'active' => true,
					],
				]
			);

			$this->add_control(
				'link',
				[
					'label' => __( 'Link', 'elementor' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => '',
					],
				]
			);

			$this->end_controls_section();

			$this->start_controls_section(
				'section_style',
				[
					'label' => __( 'Portrait-Widget', 'mb' ),
					'tab' => Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_control(
				'mb_cta_color',
				[
                    'label' => esc_html__( 'CTA Color', 'elementor' ),
                    'type' => Controls_Manager::COLOR,
                    'global' => [
                        'default' => Global_Colors::COLOR_PRIMARY,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mb-cta .mb-cta__content' => 'background: {{VALUE}};',
                    ],
				]
			);

			$this->end_controls_section();
		}

		/**
		 *
		 *
		 */
		protected function render() {
			$settings = $this->get_settings_for_display();

			if ( ! empty( $settings['link']['url'] ) ) {
				$this->add_link_attributes( 'url', $settings['link'] );
			}

			?>
			<div class="mb-cta">
				<a <?php echo $this->get_render_attribute_string( 'url' ) ?>>
					<div class="mb-cta__overlay" <?php echo $this->get_render_attribute_string( 'default_image' ) ?>>
                        <div class="mb-cta__content">
                            <?php if($settings['title']): ?>
                            <h3 class="mb-cta__title"><?php echo esc_html($settings['title']); ?></h3>
                            <?php endif; ?>
                        </div>
                    </div>
				</a>
			</div>
			<?php
		}

	}
